@@ -44,6 +44,7 @@ class Deploys(object):
         current_version = kargs.get('current_version')
         previous_version = kargs.get('previous_version')
         diff_content = kargs.get('diff_content')
+        project_metrics = kargs.get('project_metrics')
 
         files = {
             'api_code': (None, project_code),
@@ -55,6 +56,13 @@ class Deploys(object):
             'deploy[previous_version][tag]': (None, previous_version.get('tag')),  # noqa: E501
         }
 
+        if project_metrics:
+            total_lines = project_metrics.get('total_lines')
+
+            files.update({
+                'deploy[project][metrics][total_lines]': (None, total_lines),
+            })
+
         if diff_content:
             self._assert_filepointer_is_at_beginning(diff_content)
             diff_content_args = (
