@@ -2,6 +2,7 @@ import tempfile
 import re
 import warnings
 
+
 class GitAdapter(object):
     LIST_OPTION = '--list'
     SORT_OPTION = '--sort'
@@ -29,10 +30,11 @@ class GitAdapter(object):
         version = version or self.EMPTY_REPOSITORY_HASH
 
         if version == self.EMPTY_REPOSITORY_HASH:
+            msg_fmt = """Creating diff comparing revision[{0}]
+            and the repository beginning"""
+
             warnings.warn(
-                "Creating diff comparing revision[{0}] and the repository beginning".format(
-                    another_version
-                )
+                msg_fmt.format(another_version)
             )
 
         diff_file = tempfile.TemporaryFile()
@@ -80,7 +82,6 @@ class GitAdapter(object):
     def previous_commit(self):
         return self.previous_commit_from(self.current_commit)
 
-
     def previous_commit_from(self, commit, offset=1):
         if self.commit_is_first(commit):
             return self.EMPTY_REPOSITORY_HASH
@@ -100,7 +101,9 @@ class GitAdapter(object):
 
     def show_commit_refs(self, commit):
         with tempfile.TemporaryFile() as client_output:
-            self._git_client.show_ref("--head", "--heads", "--tags", output_stream=client_output)
+            self._git_client.show_ref(
+                "--head", "--heads", "--tags", output_stream=client_output
+            )
             refs = _read_file_lines_generator(client_output)
             refs = list(
                 filter(
@@ -122,6 +125,7 @@ class GitAdapter(object):
     def empty_repository_tree_commit(self):
         return self.EMPTY_REPOSITORY_HASH
 
+
 def _read_file_lines_generator(file):
     file.seek(0)
 
@@ -132,4 +136,4 @@ def _read_file_lines_generator(file):
         if line:
             yield line
         else:
-            break
\ No newline at end of file
+            break
